@@ -1,17 +1,19 @@
 package Finance::Bitcoin;
 
+BEGIN {
+	$Finance::Bitcoin::AUTHORITY = 'cpan:TOBYINK';
+	$Finance::Bitcoin::VERSION   = '0.900';
+}
+
 use 5.010;
-use common::sense;
+use strict;
+use warnings;
+
 use Finance::Bitcoin::API;
 use Finance::Bitcoin::Wallet;
 use Finance::Bitcoin::Address;
 use Object::AUTHORITY;
 
-BEGIN {
-	$Finance::Bitcoin::AUTHORITY = 'cpan:TOBYINK';
-	$Finance::Bitcoin::VERSION   = '0.004';
-}
-
 1;
 
 __END__
@@ -45,8 +47,13 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2010-2011 Toby Inkster
+Copyright 2010, 2011, 2013 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
