@@ -1,91 +1,62 @@
 package Finance::Bitcoin::Wallet;
 
-use 5.010;
-use common::sense;
-use Carp;
-use Finance::Bitcoin;
-use Any::Moose;
-use Object::AUTHORITY;
-use Scalar::Util qw[blessed];
-
 BEGIN {
 	$Finance::Bitcoin::Wallet::AUTHORITY = 'cpan:TOBYINK';
-	$Finance::Bitcoin::Wallet::VERSION   = '0.004';
+	$Finance::Bitcoin::Wallet::VERSION   = '0.900';
 }
 
-has api => (is => 'rw');
+use 5.010;
+use Moo;
 
-around BUILDARGS => sub
-{
-	my $orig  = shift;
-	my $class = shift;
+use Carp;
+use Finance::Bitcoin;
+use Object::AUTHORITY;
+use Scalar::Util qw( blessed );
 
-	if (scalar @_ == 1
-	and (blessed($_[0]) || $_[0] =~ /^http/))
-	{
-		my ($api) = @_;
-
-		unless (blessed($api) and $api->isa('Finance::Bitcoin::API'))
-		{
-			$api = $api ? 
-				Finance::Bitcoin::API->new(endpoint=>"$api") : 
-				Finance::Bitcoin::API->new;
-		}
-
-		return $class->$orig(api => $api);
-	}
-	
-	else
-	{
-		return $class->$orig(@_);
-	}
-};
+with "Finance::Bitcoin::Role::HasAPI";
 
 sub balance
 {
-	my ($self) = @_;
+	my $self = shift;
 	return $self->api->call('getbalance');
 }
 
 sub pay
 {
-	my ($self, $address, $amount) = @_;
-
-	croak "Must provide an address"
-		unless $address;
-	croak "Must provide an amount"
-		unless $amount;
-		
-	if (blessed($address))
-	{
-		$address = $address->address;
-	}
+	my $self = shift;
+	my ($address, $amount) = @_;
 	
-	return $self->api->call('sendtoaddress', $address, $amount);
+	croak "Must provide an address" unless $address;
+	croak "Must provide an amount"  unless $amount;
+	
+	$address = $address->address if blessed $address;
+	
+	return $self->api->call(sendtoaddress => $address, $amount);
 }
 
 sub create_address
 {
-	my ($self, $label) = @_;
+	my $self = shift;
+	my ($label) = @_;
+	
 	my $address_id = $self->api->call('getnewaddress');
-	my $address    = Finance::Bitcoin::Address->new($self->api, $address_id);
-	$address->label($label)
-		if $label;
+	my $address = "Finance::Bitcoin::Address"->new($self->api, $address_id);
+	$address->label($label) if $label;
+	
 	return $address;
 }
 
 sub addresses
 {
 	my ($self) = @_;
-	my $list   = $self->api->call('listreceivedbyaddress', 0, JSON::true);
+	
+	my $list = $self->api->call('listreceivedbyaddress', 0, JSON::true);
+	return unless ref($list) eq 'ARRAY';
 	
 	return
-		map { Finance::Bitcoin::Address->new($self->api, $_->{address}); }
-			grep { $_->{amount} > 0 }
-				@$list
-		if ref $list eq 'ARRAY';
-		
-	return;
+		map  { "Finance::Bitcoin::Address"->new($self->api, $_->{address}); }
+		grep { $_->{amount} > 0 }
+		@$list;
 }
 
 1;
@@ -124,6 +95,12 @@ Bitcoin instance.
 Constructor. $endpoint may be the JSON RPC endpoint URL, or may be a
 Finance::Bitcoin::API object.
 
+=begin trustme
+
+=item BUILDARGS
+
+=end trustme
+
 =item C<< balance >>
 
 Returns the current balance of the wallet.
@@ -170,8 +147,13 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2010-2011 Toby Inkster
+Copyright 2010, 2011, 2013 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
